#mptlinux driver
#Authors: Greg Cymbalski, Joel Diaz, Don S. Lee, Adrian Rodriguez, Ram Pai, E.Javier Figueroa

#Basic information: vendor, driver name, driver version
%define provider lsi
%define rname mptlinux
%define rversion 3.16.00.00

#From here on out, you can safely copy/paste everything that sets up the 
#variables we'll need.  
#Where modules live.
%define _libexecdir /lib/modules

#Make sure to export the environment variable $BUILD_KERNEL
#before making this RPM!
#it should look like the result of a 'uname -r'
# export BUILD_KERNEL="2.6.9-11.ELlargesmp"
#at which point the driver will be compiled against whatever
# /lib/modules/$BUILD_KERNEL/build points to...
#or, if the $BUILD_KERNEL is not defined, we'll build against the current kernel/flavor.

#What follows is basically magic: splitkernel will contain only the kernel version of the intended kernel as described above, and kflavor will contain the intended flavor (the difference between kflavor and myflavor being that kflavor will report 'default' if the normal flavor is intended).
%define splitkernel %( if [ -z $BUILD_KERNEL ]; then ( echo "`uname -r`" | sed -e "s|EL.*|EL|" ); else ( echo "$BUILD_KERNEL" | sed -e "s|EL.*|EL|g"); fi )
%define splitflavor %( if [ -z $BUILD_KERNEL ]; then ( echo "`uname -r`" | sed -e "s|.*EL||" ); else ( echo "$BUILD_KERNEL" | sed -e "s|.*EL||g" ); fi)
%define myflavor %( if [ "%{splitflavor}" = "" ]; then (echo ""); else (echo "%{splitflavor}"); fi)
%define kflavor %( if [ "%{splitflavor}" = "" ]; then (echo "default"); else (echo "%{splitflavor}"); fi)

#Sets up some variables we will need later on, mostly for path purposes.
%define kver %(echo %{splitkernel} )
%define kernel %{kver}%{myflavor}

#moduledir contains the directory beneath /lib/modules/%{kernel}/ 
#	where our modules will be installed.  This is so as not to
#	contaminate the normal module tree.
%define moduledir /updates

#
# Now things get specific; everything above can be safely duplicated.
#

#Where this particular package gets built.
%define pkgbuilddir /usr/src/redhat/BUILD/%{rname}-%{rversion}

#The name of the module that is produced by the build process.
%define modules mptbase.ko mptctl.ko mptfc.ko mptspi.ko mptsas.ko
#modules existent in previous version 3.12
#mptscsih.ko mptlan.ko

Summary: Linux mptlinux driver
Name: %{provider}-%{rname}-%{kflavor}
Version: %( (echo "%{rversion}_%{kver}" | tr '-' '_') )

#Bump your release up a notch whenever you have a new revision!
Release: 1

#Make sure to update this field appropriately.
License: GPL

#Since you're packaging a module, this field shouldn't need to be touched.
Group: System Environment/Kernel
Source: mptlinux-%{rversion}.tar.gz
Distribution: linux
Vendor: IBM
Packager: Joel Diaz <joeldiaz@us.ibm.com>

BuildRoot: %{_tmppath}/root-%{name}-%{version}

#Update this field appropriately.
%description
Driver for %{rname}

%prep
%setup -n drivers/message/fusion
#echo "kernel: %{kernel}"
#echo "myflavor: %{myflavor}"
pwd

echo %{splitkernel}
echo %{kflavor}

%build
#echo "%{buildroot}"

make CONFIG_FUSION_SPI=m CONFIG_FUSION_FC=m CONFIG_FUSION_SAS=m CONFIG_FUSION_LAN=m CONFIG_FUSION_CTL=m CONFIG_DEBUG_INFO=1 V=1 -C /lib/modules/%{kernel}/build M=`pwd` modules

%install
#echo %{kernel}
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=updates
pwd
ls
%{__rm} -rf %{buildroot}/*
%{__install} -d -m0755 %{buildroot}%{_libexecdir}/%{kernel}%{moduledir}
pwd
ls
echo HERE
echo %{buildroot}%{_libexecdir}/%{kernel}%{moduledir}
echo OUTHERE

%{__mv} -f %{modules} %{buildroot}%{_libexecdir}/%{kernel}%{moduledir}

%post
# IMPORTANT: Do not change the KERNELRELEASES definition; it will be
# replaced during driver reuse!
# set variables
KERNELRELEASES=%{kernel}

# add modules to modules.conf and run depmod
echo "alias scsi_hostadapter_mptbase mptbase" >> /etc/modprobe.conf
echo "alias scsi_hostadapter_mptctl mptctl" >> /etc/modprobe.conf
echo "alias scsi_hostadapter_mptfc mptfc" >> /etc/modprobe.conf
echo "alias scsi_hostadapter_mptlan mptlan" >> /etc/modprobe.conf
echo "alias scsi_hostadapter_mptsas mptsas" >> /etc/modprobe.conf
echo "alias scsi_hostadapter_mptscsih mptscsih" >> /etc/modprobe.conf
echo "alias scsi_hostadapter_mptspi mptspi" >> /etc/modprobe.conf

# update the module dependencies for the target kernel/flavor
depmod -a -F /boot/System.map-${KERNELRELEASES} ${KERNELRELEASES}

# update initrd and grub
new-kernel-pkg -v --mkinitrd --initrdfile="/boot/initrd-${KERNELRELEASES}.update" --banner="$(cat /etc/redhat-release | sed -e 's/release.*$//')" --install ${KERNELRELEASES}


%postun
# IMPORTANT: Do not change the KERNELRELEASES definition; it will be
# replaced during driver reuse!
# set variables
KERNELRELEASES=%{kernel}

# remove modules from /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptbase.*$/d' /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptctl.*$/d' /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptfc.*$/d' /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptlan.*$/d' /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptsas.*$/d' /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptscsih.*$/d' /etc/modprobe.conf
sed -i -e '/alias scsi_hostadapter_mptspi.*$/d' /etc/modprobe.conf

# update the module dependencies for the target kernel/flavor
depmod -a -F /boot/System.map-${KERNELRELEASES} ${KERNELRELEASES}

# update initrd and grub
new-kernel-pkg -v --mkinitrd --initrdfile="/boot/initrd-${KERNELRELEASES}.update" --banner="$(cat /etc/redhat-release | sed -e 's/release.*$//')" --install ${KERNELRELEASES}


%clean
%{__rm} -rf %{buildroot}/%{rname}-%{rversion}

#Define the package for each flavor and list the corresponding files in %files for them.
#This section should not require significant (if any) modification.
%files
%defattr(-, root, root, 0755)
%{_libexecdir}/%{kernel}%{moduledir}/

%changelog
* Wed Oct 05 2008 E J Figueroa
- Modified for version 3.16.00.00
- Removed lines with patches
- Removed mptlan.ko and mptscsih.ko from modules array
* Fri Sep 12 2008 E J Figueroa
- Changed version and release numbers
* Tue Oct 10 2006 Joel Diaz
- Changed export variable to $BUILD_KERNEL
* Mon Sep 25 2006 Joel Diaz
- Modified for building aacraid.ko and mptsas.ko
* Thu Sep 07 2006 Joel Diaz
- Prettyfied up the tg3.spec file
* Tue Sep 05 2006 Joel Diaz
- Modified for tg3.ko
* Tue May 30 2006 Greg Cymbalski <gcymbal@us.ibm.com> - 5.00.04
- Initial pacakage.
